==> types-aiobotocore-iotfleetwise-2.6.0.tar.gz: types-aiobotocore-iotfleetwise-2.6.0/types_aiobotocore_iotfleetwise/literals.py <==
"""
Type annotations for iotfleetwise service literal definitions.

[Open documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_iotfleetwise/literals/)

Usage::

    ```python
    from types_aiobotocore_iotfleetwise.literals import CampaignStatusType

    data: CampaignStatusType = "CREATING"
    ```
"""
import sys

if sys.version_info >= (3, 9):
    from typing import Literal
else:
    from typing_extensions import Literal


__all__ = (
    "CampaignStatusType",
    "CompressionType",
    "DataFormatType",
    "DiagnosticsModeType",
    "GetVehicleStatusPaginatorName",
    "ListCampaignsPaginatorName",
    "ListDecoderManifestNetworkInterfacesPaginatorName",
    "ListDecoderManifestSignalsPaginatorName",
    "ListDecoderManifestsPaginatorName",
    "ListFleetsForVehiclePaginatorName",
    "ListFleetsPaginatorName",
    "ListModelManifestNodesPaginatorName",
    "ListModelManifestsPaginatorName",
    "ListSignalCatalogNodesPaginatorName",
    "ListSignalCatalogsPaginatorName",
    "ListVehiclesInFleetPaginatorName",
    "ListVehiclesPaginatorName",
    "LogTypeType",
    "ManifestStatusType",
    "NetworkInterfaceTypeType",
    "NodeDataTypeType",
    "RegistrationStatusType",
    "SignalDecoderTypeType",
    "SpoolingModeType",
    "StorageCompressionFormatType",
    "TriggerModeType",
    "UpdateCampaignActionType",
    "UpdateModeType",
    "VehicleAssociationBehaviorType",
    "VehicleStateType",
    "IoTFleetWiseServiceName",
    "ServiceName",
    "ResourceServiceName",
    "PaginatorName",
    "RegionName",
)


CampaignStatusType = Literal["CREATING", "RUNNING", "SUSPENDED", "WAITING_FOR_APPROVAL"]
CompressionType = Literal["OFF", "SNAPPY"]
DataFormatType = Literal["JSON", "PARQUET"]
DiagnosticsModeType = Literal["OFF", "SEND_ACTIVE_DTCS"]
GetVehicleStatusPaginatorName = Literal["get_vehicle_status"]
ListCampaignsPaginatorName = Literal["list_campaigns"]
ListDecoderManifestNetworkInterfacesPaginatorName = Literal[
    "list_decoder_manifest_network_interfaces"
]
ListDecoderManifestSignalsPaginatorName = Literal["list_decoder_manifest_signals"]
ListDecoderManifestsPaginatorName = Literal["list_decoder_manifests"]
ListFleetsForVehiclePaginatorName = Literal["list_fleets_for_vehicle"]
ListFleetsPaginatorName = Literal["list_fleets"]
ListModelManifestNodesPaginatorName = Literal["list_model_manifest_nodes"]
ListModelManifestsPaginatorName = Literal["list_model_manifests"]
ListSignalCatalogNodesPaginatorName = Literal["list_signal_catalog_nodes"]
ListSignalCatalogsPaginatorName = Literal["list_signal_catalogs"]
ListVehiclesInFleetPaginatorName = Literal["list_vehicles_in_fleet"]
ListVehiclesPaginatorName = Literal["list_vehicles"]
LogTypeType = Literal["ERROR", "OFF"]
ManifestStatusType = Literal["ACTIVE", "DRAFT"]
NetworkInterfaceTypeType = Literal["CAN_INTERFACE", "OBD_INTERFACE"]
NodeDataTypeType = Literal[
    "BOOLEAN",
    "BOOLEAN_ARRAY",
    "DOUBLE",
    "DOUBLE_ARRAY",
    "FLOAT",
    "FLOAT_ARRAY",
    "INT16",
    "INT16_ARRAY",
    "INT32",
    "INT32_ARRAY",
    "INT64",
    "INT64_ARRAY",
    "INT8",
    "INT8_ARRAY",
    "STRING",
    "STRING_ARRAY",
    "UINT16",
    "UINT16_ARRAY",
    "UINT32",
    "UINT32_ARRAY",
    "UINT64",
    "UINT64_ARRAY",
    "UINT8",
    "UINT8_ARRAY",
    "UNIX_TIMESTAMP",
    "UNIX_TIMESTAMP_ARRAY",
    "UNKNOWN",
]
RegistrationStatusType = Literal[
    "REGISTRATION_FAILURE", "REGISTRATION_PENDING", "REGISTRATION_SUCCESS"
]
SignalDecoderTypeType = Literal["CAN_SIGNAL", "OBD_SIGNAL"]
SpoolingModeType = Literal["OFF", "TO_DISK"]
StorageCompressionFormatType = Literal["GZIP", "NONE"]
TriggerModeType = Literal["ALWAYS", "RISING_EDGE"]
UpdateCampaignActionType = Literal["APPROVE", "RESUME", "SUSPEND", "UPDATE"]
UpdateModeType = Literal["Merge", "Overwrite"]
VehicleAssociationBehaviorType = Literal["CreateIotThing", "ValidateIotThingExists"]
VehicleStateType = Literal["CREATED", "DELETING", "HEALTHY", "READY", "SUSPENDED"]
IoTFleetWiseServiceName = Literal["iotfleetwise"]
ServiceName = Literal[
    "accessanalyzer",
    "account",
    "acm",
    "acm-pca",
    "alexaforbusiness",
    "amp",
    "amplify",
    "amplifybackend",
    "amplifyuibuilder",
    "apigateway",
    "apigatewaymanagementapi",
    "apigatewayv2",
    "appconfig",
    "appconfigdata",
    "appfabric",
    "appflow",
    "appintegrations",
    "application-autoscaling",
    "application-insights",
    "applicationcostprofiler",
    "appmesh",
    "apprunner",
    "appstream",
    "appsync",
    "arc-zonal-shift",
    "athena",
    "auditmanager",
    "autoscaling",
    "autoscaling-plans",
    "backup",
    "backup-gateway",
    "backupstorage",
    "batch",
    "billingconductor",
    "braket",
    "budgets",
    "ce",
    "chime",
    "chime-sdk-identity",
    "chime-sdk-media-pipelines",
    "chime-sdk-meetings",
    "chime-sdk-messaging",
    "chime-sdk-voice",
    "cleanrooms",
    "cloud9",
    "cloudcontrol",
    "clouddirectory",
    "cloudformation",
    "cloudfront",
    "cloudhsm",
    "cloudhsmv2",
    "cloudsearch",
    "cloudsearchdomain",
    "cloudtrail",
    "cloudtrail-data",
    "cloudwatch",
    "codeartifact",
    "codebuild",
    "codecatalyst",
    "codecommit",
    "codedeploy",
    "codeguru-reviewer",
    "codeguru-security",
    "codeguruprofiler",
    "codepipeline",
    "codestar",
    "codestar-connections",
    "codestar-notifications",
    "cognito-identity",
    "cognito-idp",
    "cognito-sync",
    "comprehend",
    "comprehendmedical",
    "compute-optimizer",
    "config",
    "connect",
    "connect-contact-lens",
    "connectcampaigns",
    "connectcases",
    "connectparticipant",
    "controltower",
    "cur",
    "customer-profiles",
    "databrew",
    "dataexchange",
    "datapipeline",
    "datasync",
    "dax",
    "detective",
    "devicefarm",
    "devops-guru",
    "directconnect",
    "discovery",
    "dlm",
    "dms",
    "docdb",
    "docdb-elastic",
    "drs",
    "ds",
    "dynamodb",
    "dynamodbstreams",
    "ebs",
    "ec2",
    "ec2-instance-connect",
    "ecr",
    "ecr-public",
    "ecs",
    "efs",
    "eks",
    "elastic-inference",
    "elasticache",
    "elasticbeanstalk",
    "elastictranscoder",
    "elb",
    "elbv2",
    "emr",
    "emr-containers",
    "emr-serverless",
    "entityresolution",
    "es",
    "events",
    "evidently",
    "finspace",
    "finspace-data",
    "firehose",
    "fis",
    "fms",
    "forecast",
    "forecastquery",
    "frauddetector",
    "fsx",
    "gamelift",
    "gamesparks",
    "glacier",
    "globalaccelerator",
    "glue",
    "grafana",
    "greengrass",
    "greengrassv2",
    "groundstation",
    "guardduty",
    "health",
    "healthlake",
    "honeycode",
    "iam",
    "identitystore",
    "imagebuilder",
    "importexport",
    "inspector",
    "inspector2",
    "internetmonitor",
    "iot",
    "iot-data",
    "iot-jobs-data",
    "iot-roborunner",
    "iot1click-devices",
    "iot1click-projects",
    "iotanalytics",
    "iotdeviceadvisor",
    "iotevents",
    "iotevents-data",
    "iotfleethub",
    "iotfleetwise",
    "iotsecuretunneling",
    "iotsitewise",
    "iotthingsgraph",
    "iottwinmaker",
    "iotwireless",
    "ivs",
    "ivs-realtime",
    "ivschat",
    "kafka",
    "kafkaconnect",
    "kendra",
    "kendra-ranking",
    "keyspaces",
    "kinesis",
    "kinesis-video-archived-media",
    "kinesis-video-media",
    "kinesis-video-signaling",
    "kinesis-video-webrtc-storage",
    "kinesisanalytics",
    "kinesisanalyticsv2",
    "kinesisvideo",
    "kms",
    "lakeformation",
    "lambda",
    "lex-models",
    "lex-runtime",
    "lexv2-models",
    "lexv2-runtime",
    "license-manager",
    "license-manager-linux-subscriptions",
    "license-manager-user-subscriptions",
    "lightsail",
    "location",
    "logs",
    "lookoutequipment",
    "lookoutmetrics",
    "lookoutvision",
    "m2",
    "machinelearning",
    "macie",
    "macie2",
    "managedblockchain",
    "managedblockchain-query",
    "marketplace-catalog",
    "marketplace-entitlement",
    "marketplacecommerceanalytics",
    "mediaconnect",
    "mediaconvert",
    "medialive",
    "mediapackage",
    "mediapackage-vod",
    "mediapackagev2",
    "mediastore",
    "mediastore-data",
    "mediatailor",
    "medical-imaging",
    "memorydb",
    "meteringmarketplace",
    "mgh",
    "mgn",
    "migration-hub-refactor-spaces",
    "migrationhub-config",
    "migrationhuborchestrator",
    "migrationhubstrategy",
    "mobile",
    "mq",
    "mturk",
    "mwaa",
    "neptune",
    "network-firewall",
    "networkmanager",
    "nimble",
    "oam",
    "omics",
    "opensearch",
    "opensearchserverless",
    "opsworks",
    "opsworkscm",
    "organizations",
    "osis",
    "outposts",
    "panorama",
    "payment-cryptography",
    "payment-cryptography-data",
    "personalize",
    "personalize-events",
    "personalize-runtime",
    "pi",
    "pinpoint",
    "pinpoint-email",
    "pinpoint-sms-voice",
    "pinpoint-sms-voice-v2",
    "pipes",
    "polly",
    "pricing",
    "privatenetworks",
    "proton",
    "qldb",
    "qldb-session",
    "quicksight",
    "ram",
    "rbin",
    "rds",
    "rds-data",
    "redshift",
    "redshift-data",
    "redshift-serverless",
    "rekognition",
    "resiliencehub",
    "resource-explorer-2",
    "resource-groups",
    "resourcegroupstaggingapi",
    "robomaker",
    "rolesanywhere",
    "route53",
    "route53-recovery-cluster",
    "route53-recovery-control-config",
    "route53-recovery-readiness",
    "route53domains",
    "route53resolver",
    "rum",
    "s3",
    "s3control",
    "s3outposts",
    "sagemaker",
    "sagemaker-a2i-runtime",
    "sagemaker-edge",
    "sagemaker-featurestore-runtime",
    "sagemaker-geospatial",
    "sagemaker-metrics",
    "sagemaker-runtime",
    "savingsplans",
    "scheduler",
    "schemas",
    "sdb",
    "secretsmanager",
    "securityhub",
    "securitylake",
    "serverlessrepo",
    "service-quotas",
    "servicecatalog",
    "servicecatalog-appregistry",
    "servicediscovery",
    "ses",
    "sesv2",
    "shield",
    "signer",
    "simspaceweaver",
    "sms",
    "sms-voice",
    "snow-device-management",
    "snowball",
    "sns",
    "sqs",
    "ssm",
    "ssm-contacts",
    "ssm-incidents",
    "ssm-sap",
    "sso",
    "sso-admin",
    "sso-oidc",
    "stepfunctions",
    "storagegateway",
    "sts",
    "support",
    "support-app",
    "swf",
    "synthetics",
    "textract",
    "timestream-query",
    "timestream-write",
    "tnb",
    "transcribe",
    "transfer",
    "translate",
    "verifiedpermissions",
    "voice-id",
    "vpc-lattice",
    "waf",
    "waf-regional",
    "wafv2",
    "wellarchitected",
    "wisdom",
    "workdocs",
    "worklink",
    "workmail",
    "workmailmessageflow",
    "workspaces",
    "workspaces-web",
    "xray",
]
ResourceServiceName = Literal[
    "cloudformation",
    "cloudwatch",
    "dynamodb",
    "ec2",
    "glacier",
    "iam",
    "opsworks",
    "s3",
    "sns",
    "sqs",
]
PaginatorName = Literal[
    "get_vehicle_status",
    "list_campaigns",
    "list_decoder_manifest_network_interfaces",
    "list_decoder_manifest_signals",
    "list_decoder_manifests",
    "list_fleets",
    "list_fleets_for_vehicle",
    "list_model_manifest_nodes",
    "list_model_manifests",
    "list_signal_catalog_nodes",
    "list_signal_catalogs",
    "list_vehicles",
    "list_vehicles_in_fleet",
]
RegionName = Literal["eu-central-1", "us-east-1"]

==> types-aiobotocore-iotfleetwise-2.8.0.tar.gz: types-aiobotocore-iotfleetwise-2.8.0/types_aiobotocore_iotfleetwise/literals.py <==
"""
Type annotations for iotfleetwise service literal definitions.

[Open documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_iotfleetwise/literals/)

Usage::

    ```python
    from types_aiobotocore_iotfleetwise.literals import CampaignStatusType

    data: CampaignStatusType = "CREATING"
    ```
"""

import sys

if sys.version_info >= (3, 12):
    from typing import Literal
else:
    from typing_extensions import Literal


__all__ = (
    "CampaignStatusType",
    "CompressionType",
    "DataFormatType",
    "DiagnosticsModeType",
    "EncryptionStatusType",
    "EncryptionTypeType",
    "GetVehicleStatusPaginatorName",
    "ListCampaignsPaginatorName",
    "ListDecoderManifestNetworkInterfacesPaginatorName",
    "ListDecoderManifestSignalsPaginatorName",
    "ListDecoderManifestsPaginatorName",
    "ListFleetsForVehiclePaginatorName",
    "ListFleetsPaginatorName",
    "ListModelManifestNodesPaginatorName",
    "ListModelManifestsPaginatorName",
    "ListSignalCatalogNodesPaginatorName",
    "ListSignalCatalogsPaginatorName",
    "ListVehiclesInFleetPaginatorName",
    "ListVehiclesPaginatorName",
    "LogTypeType",
    "ManifestStatusType",
    "NetworkInterfaceTypeType",
    "NodeDataEncodingType",
    "NodeDataTypeType",
    "ROS2PrimitiveTypeType",
    "RegistrationStatusType",
    "SignalDecoderTypeType",
    "SpoolingModeType",
    "StorageCompressionFormatType",
    "StructuredMessageListTypeType",
    "TriggerModeType",
    "UpdateCampaignActionType",
    "UpdateModeType",
    "VehicleAssociationBehaviorType",
    "VehicleMiddlewareProtocolType",
    "VehicleStateType",
    "IoTFleetWiseServiceName",
    "ServiceName",
    "ResourceServiceName",
    "PaginatorName",
    "RegionName",
)


CampaignStatusType = Literal["CREATING", "RUNNING", "SUSPENDED", "WAITING_FOR_APPROVAL"]
CompressionType = Literal["OFF", "SNAPPY"]
DataFormatType = Literal["JSON", "PARQUET"]
DiagnosticsModeType = Literal["OFF", "SEND_ACTIVE_DTCS"]
EncryptionStatusType = Literal["FAILURE", "PENDING", "SUCCESS"]
EncryptionTypeType = Literal["FLEETWISE_DEFAULT_ENCRYPTION", "KMS_BASED_ENCRYPTION"]
GetVehicleStatusPaginatorName = Literal["get_vehicle_status"]
ListCampaignsPaginatorName = Literal["list_campaigns"]
ListDecoderManifestNetworkInterfacesPaginatorName = Literal[
    "list_decoder_manifest_network_interfaces"
]
ListDecoderManifestSignalsPaginatorName = Literal["list_decoder_manifest_signals"]
ListDecoderManifestsPaginatorName = Literal["list_decoder_manifests"]
ListFleetsForVehiclePaginatorName = Literal["list_fleets_for_vehicle"]
ListFleetsPaginatorName = Literal["list_fleets"]
ListModelManifestNodesPaginatorName = Literal["list_model_manifest_nodes"]
ListModelManifestsPaginatorName = Literal["list_model_manifests"]
ListSignalCatalogNodesPaginatorName = Literal["list_signal_catalog_nodes"]
ListSignalCatalogsPaginatorName = Literal["list_signal_catalogs"]
ListVehiclesInFleetPaginatorName = Literal["list_vehicles_in_fleet"]
ListVehiclesPaginatorName = Literal["list_vehicles"]
LogTypeType = Literal["ERROR", "OFF"]
ManifestStatusType = Literal["ACTIVE", "DRAFT", "INVALID", "VALIDATING"]
NetworkInterfaceTypeType = Literal[
    "CAN_INTERFACE", "CUSTOMER_DECODED_INTERFACE", "OBD_INTERFACE", "VEHICLE_MIDDLEWARE"
]
NodeDataEncodingType = Literal["BINARY", "TYPED"]
NodeDataTypeType = Literal[
    "BOOLEAN",
    "BOOLEAN_ARRAY",
    "DOUBLE",
    "DOUBLE_ARRAY",
    "FLOAT",
    "FLOAT_ARRAY",
    "INT16",
    "INT16_ARRAY",
    "INT32",
    "INT32_ARRAY",
    "INT64",
    "INT64_ARRAY",
    "INT8",
    "INT8_ARRAY",
    "STRING",
    "STRING_ARRAY",
    "STRUCT",
    "STRUCT_ARRAY",
    "UINT16",
    "UINT16_ARRAY",
    "UINT32",
    "UINT32_ARRAY",
    "UINT64",
    "UINT64_ARRAY",
    "UINT8",
    "UINT8_ARRAY",
    "UNIX_TIMESTAMP",
    "UNIX_TIMESTAMP_ARRAY",
    "UNKNOWN",
]
ROS2PrimitiveTypeType = Literal[
    "BOOL",
    "BYTE",
    "CHAR",
    "FLOAT32",
    "FLOAT64",
    "INT16",
    "INT32",
    "INT64",
    "INT8",
    "STRING",
    "UINT16",
    "UINT32",
    "UINT64",
    "UINT8",
    "WSTRING",
]
RegistrationStatusType = Literal[
    "REGISTRATION_FAILURE", "REGISTRATION_PENDING", "REGISTRATION_SUCCESS"
]
SignalDecoderTypeType = Literal[
    "CAN_SIGNAL", "CUSTOMER_DECODED_SIGNAL", "MESSAGE_SIGNAL", "OBD_SIGNAL"
]
SpoolingModeType = Literal["OFF", "TO_DISK"]
StorageCompressionFormatType = Literal["GZIP", "NONE"]
StructuredMessageListTypeType = Literal[
    "DYNAMIC_BOUNDED_CAPACITY", "DYNAMIC_UNBOUNDED_CAPACITY", "FIXED_CAPACITY"
]
TriggerModeType = Literal["ALWAYS", "RISING_EDGE"]
UpdateCampaignActionType = Literal["APPROVE", "RESUME", "SUSPEND", "UPDATE"]
UpdateModeType = Literal["Merge", "Overwrite"]
VehicleAssociationBehaviorType = Literal["CreateIotThing", "ValidateIotThingExists"]
VehicleMiddlewareProtocolType = Literal["ROS_2"]
VehicleStateType = Literal["CREATED", "DELETING", "HEALTHY", "READY", "SUSPENDED"]
IoTFleetWiseServiceName = Literal["iotfleetwise"]
ServiceName = Literal[
    "accessanalyzer",
    "account",
    "acm",
    "acm-pca",
    "alexaforbusiness",
    "amp",
    "amplify",
    "amplifybackend",
    "amplifyuibuilder",
    "apigateway",
    "apigatewaymanagementapi",
    "apigatewayv2",
    "appconfig",
    "appconfigdata",
    "appfabric",
    "appflow",
    "appintegrations",
    "application-autoscaling",
    "application-insights",
    "applicationcostprofiler",
    "appmesh",
    "apprunner",
    "appstream",
    "appsync",
    "arc-zonal-shift",
    "athena",
    "auditmanager",
    "autoscaling",
    "autoscaling-plans",
    "b2bi",
    "backup",
    "backup-gateway",
    "backupstorage",
    "batch",
    "bcm-data-exports",
    "bedrock",
    "bedrock-runtime",
    "billingconductor",
    "braket",
    "budgets",
    "ce",
    "chime",
    "chime-sdk-identity",
    "chime-sdk-media-pipelines",
    "chime-sdk-meetings",
    "chime-sdk-messaging",
    "chime-sdk-voice",
    "cleanrooms",
    "cloud9",
    "cloudcontrol",
    "clouddirectory",
    "cloudformation",
    "cloudfront",
    "cloudfront-keyvaluestore",
    "cloudhsm",
    "cloudhsmv2",
    "cloudsearch",
    "cloudsearchdomain",
    "cloudtrail",
    "cloudtrail-data",
    "cloudwatch",
    "codeartifact",
    "codebuild",
    "codecatalyst",
    "codecommit",
    "codedeploy",
    "codeguru-reviewer",
    "codeguru-security",
    "codeguruprofiler",
    "codepipeline",
    "codestar",
    "codestar-connections",
    "codestar-notifications",
    "cognito-identity",
    "cognito-idp",
    "cognito-sync",
    "comprehend",
    "comprehendmedical",
    "compute-optimizer",
    "config",
    "connect",
    "connect-contact-lens",
    "connectcampaigns",
    "connectcases",
    "connectparticipant",
    "controltower",
    "cost-optimization-hub",
    "cur",
    "customer-profiles",
    "databrew",
    "dataexchange",
    "datapipeline",
    "datasync",
    "datazone",
    "dax",
    "detective",
    "devicefarm",
    "devops-guru",
    "directconnect",
    "discovery",
    "dlm",
    "dms",
    "docdb",
    "docdb-elastic",
    "drs",
    "ds",
    "dynamodb",
    "dynamodbstreams",
    "ebs",
    "ec2",
    "ec2-instance-connect",
    "ecr",
    "ecr-public",
    "ecs",
    "efs",
    "eks",
    "eks-auth",
    "elastic-inference",
    "elasticache",
    "elasticbeanstalk",
    "elastictranscoder",
    "elb",
    "elbv2",
    "emr",
    "emr-containers",
    "emr-serverless",
    "entityresolution",
    "es",
    "events",
    "evidently",
    "finspace",
    "finspace-data",
    "firehose",
    "fis",
    "fms",
    "forecast",
    "forecastquery",
    "frauddetector",
    "freetier",
    "fsx",
    "gamelift",
    "glacier",
    "globalaccelerator",
    "glue",
    "grafana",
    "greengrass",
    "greengrassv2",
    "groundstation",
    "guardduty",
    "health",
    "healthlake",
    "honeycode",
    "iam",
    "identitystore",
    "imagebuilder",
    "importexport",
    "inspector",
    "inspector-scan",
    "inspector2",
    "internetmonitor",
    "iot",
    "iot-data",
    "iot-jobs-data",
    "iot-roborunner",
    "iot1click-devices",
    "iot1click-projects",
    "iotanalytics",
    "iotdeviceadvisor",
    "iotevents",
    "iotevents-data",
    "iotfleethub",
    "iotfleetwise",
    "iotsecuretunneling",
    "iotsitewise",
    "iotthingsgraph",
    "iottwinmaker",
    "iotwireless",
    "ivs",
    "ivs-realtime",
    "ivschat",
    "kafka",
    "kafkaconnect",
    "kendra",
    "kendra-ranking",
    "keyspaces",
    "kinesis",
    "kinesis-video-archived-media",
    "kinesis-video-media",
    "kinesis-video-signaling",
    "kinesis-video-webrtc-storage",
    "kinesisanalytics",
    "kinesisanalyticsv2",
    "kinesisvideo",
    "kms",
    "lakeformation",
    "lambda",
    "launch-wizard",
    "lex-models",
    "lex-runtime",
    "lexv2-models",
    "lexv2-runtime",
    "license-manager",
    "license-manager-linux-subscriptions",
    "license-manager-user-subscriptions",
    "lightsail",
    "location",
    "logs",
    "lookoutequipment",
    "lookoutmetrics",
    "lookoutvision",
    "m2",
    "machinelearning",
    "macie2",
    "managedblockchain",
    "managedblockchain-query",
    "marketplace-catalog",
    "marketplace-entitlement",
    "marketplacecommerceanalytics",
    "mediaconnect",
    "mediaconvert",
    "medialive",
    "mediapackage",
    "mediapackage-vod",
    "mediapackagev2",
    "mediastore",
    "mediastore-data",
    "mediatailor",
    "medical-imaging",
    "memorydb",
    "meteringmarketplace",
    "mgh",
    "mgn",
    "migration-hub-refactor-spaces",
    "migrationhub-config",
    "migrationhuborchestrator",
    "migrationhubstrategy",
    "mobile",
    "mq",
    "mturk",
    "mwaa",
    "neptune",
    "neptunedata",
    "network-firewall",
    "networkmanager",
    "nimble",
    "oam",
    "omics",
    "opensearch",
    "opensearchserverless",
    "opsworks",
    "opsworkscm",
    "organizations",
    "osis",
    "outposts",
    "panorama",
    "payment-cryptography",
    "payment-cryptography-data",
    "pca-connector-ad",
    "personalize",
    "personalize-events",
    "personalize-runtime",
    "pi",
    "pinpoint",
    "pinpoint-email",
    "pinpoint-sms-voice",
    "pinpoint-sms-voice-v2",
    "pipes",
    "polly",
    "pricing",
    "privatenetworks",
    "proton",
    "qldb",
    "qldb-session",
    "quicksight",
    "ram",
    "rbin",
    "rds",
    "rds-data",
    "redshift",
    "redshift-data",
    "redshift-serverless",
    "rekognition",
    "repostspace",
    "resiliencehub",
    "resource-explorer-2",
    "resource-groups",
    "resourcegroupstaggingapi",
    "robomaker",
    "rolesanywhere",
    "route53",
    "route53-recovery-cluster",
    "route53-recovery-control-config",
    "route53-recovery-readiness",
    "route53domains",
    "route53resolver",
    "rum",
    "s3",
    "s3control",
    "s3outposts",
    "sagemaker",
    "sagemaker-a2i-runtime",
    "sagemaker-edge",
    "sagemaker-featurestore-runtime",
    "sagemaker-geospatial",
    "sagemaker-metrics",
    "sagemaker-runtime",
    "savingsplans",
    "scheduler",
    "schemas",
    "sdb",
    "secretsmanager",
    "securityhub",
    "securitylake",
    "serverlessrepo",
    "service-quotas",
    "servicecatalog",
    "servicecatalog-appregistry",
    "servicediscovery",
    "ses",
    "sesv2",
    "shield",
    "signer",
    "simspaceweaver",
    "sms",
    "sms-voice",
    "snow-device-management",
    "snowball",
    "sns",
    "sqs",
    "ssm",
    "ssm-contacts",
    "ssm-incidents",
    "ssm-sap",
    "sso",
    "sso-admin",
    "sso-oidc",
    "stepfunctions",
    "storagegateway",
    "sts",
    "support",
    "support-app",
    "swf",
    "synthetics",
    "textract",
    "timestream-query",
    "timestream-write",
    "tnb",
    "transcribe",
    "transfer",
    "translate",
    "trustedadvisor",
    "verifiedpermissions",
    "voice-id",
    "vpc-lattice",
    "waf",
    "waf-regional",
    "wafv2",
    "wellarchitected",
    "wisdom",
    "workdocs",
    "worklink",
    "workmail",
    "workmailmessageflow",
    "workspaces",
    "workspaces-thin-client",
    "workspaces-web",
    "xray",
]
ResourceServiceName = Literal[
    "cloudformation",
    "cloudwatch",
    "dynamodb",
    "ec2",
    "glacier",
    "iam",
    "opsworks",
    "s3",
    "sns",
    "sqs",
]
PaginatorName = Literal[
    "get_vehicle_status",
    "list_campaigns",
    "list_decoder_manifest_network_interfaces",
    "list_decoder_manifest_signals",
    "list_decoder_manifests",
    "list_fleets",
    "list_fleets_for_vehicle",
    "list_model_manifest_nodes",
    "list_model_manifests",
    "list_signal_catalog_nodes",
    "list_signal_catalogs",
    "list_vehicles",
    "list_vehicles_in_fleet",
]
RegionName = Literal["eu-central-1", "us-east-1"]
